package org.openxma.addons.ui.table.customizer.xma.client;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;

/**
 * A customizable ContextMenuItem.
 * Visually it is represented by a text and icon, while the logic whether the item is shown and what happens on selection has to be implemented explicitly.
 * 
 * @since 5.0.6
 */
public abstract class ContextMenuItem {
    private MenuItem item;
    private final String text;
    private final Image icon;

    //Default value indicating a separator - NULL!
    public final static ContextMenuItem SEPARATOR = null;

    /**
     * @param text The text to be displayed.
     * @param icon The icon to be displayed.
     */
    public ContextMenuItem(String text, Image icon) {
        this.text = text;
        this.icon = icon;
    }

    /**
     * 
     * @return The text to be displayed. Overwrite to dynamically customize appearance.
     */
    public String getText() {
        return text;
    }

    /**
     * @return The icon to be displayed.
     */
    public Image getIcon() {
        return icon;
    }

    /**
     * Implement this to control whether the item should be shown or not.
     * 
     * @see ContextMenuHelper#getContext()
     */
    protected abstract boolean isVisible();

    /**
     * Implement this to control what happens on selection.
     * 
     */
    protected abstract void executeFunction();

    void build(Menu menu, Listener listener) {
        item = new MenuItem(menu, menu.getStyle());
        item.setText(getText());
        item.setImage(getIcon());
        item.addListener(SWT.Selection, listener);
    }

    /**
     * return The {@link MenuItem}
     */
    MenuItem getItem() {
        return item;
    }
}